part2

Function part2 

pub fn part2(input: &Dance) -> String
Repeatedly applying a transformation to itself allows the computation of exponentially more dances, until reaching the complete 1 billion transformations.